/* sqlplugin.h (plugin) */

/***********************************************************************
*  This code is part of Statistics for MySQL.
*
*  Copyright (C) 2011 Heinrich Schuchardt (xypron.glpk@gmx.de)
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
***********************************************************************/

/**
 * @file sqlplugin.h
 * @brief Definition of structures needed to implement a plugin.
 * sqlstat is implemented as a replication plugin because the interface
 * version number tends to be kept constant.
 */
 
#ifndef SQLPLUGIN
#define SQLPLUGIN

#if defined HAVE_CONFIG_H
#include "config.h"
#endif // HAVE_CONFIG_H

#ifdef __cplusplus
extern "C"
{
#endif

/**
 * @brief Udf plugin information.
 */
struct udf_plugin_info {
  int interface_version;
  } plugin_info =
{ 0 };

/**
 * @brief Plugin version.
 */
char *version_value;

MYSQL_SYSVAR_STR(version, version_value, PLUGIN_VAR_READONLY, 
  "Statistics for MySQL release", NULL, NULL, VERSION);

/**
 * @brief System variables definition.
 */
struct st_mysql_sys_var* plugin_sys_var[] = {
  MYSQL_SYSVAR(version),
  NULL
};

mysql_declare_plugin(sqlstat_plugin)
{
MYSQL_UDF_PLUGIN,
&plugin_info,
"libsqlstat",
"Heinrich Schuchardt (xypron.glpk@gmx.de)",
"Statistics for MySQL (http://sqlstat.sourceforge.net)",
PLUGIN_LICENSE_PROPRIETARY,
sqlstat_plugin_init,
sqlstat_plugin_deinit,
0x0009, // 0.9
NULL,
plugin_sys_var,
NULL
}
mysql_declare_plugin_end;

#ifdef __cplusplus
}
#endif

#endif // SQLPLUGIN
