/* sqlthread.h (Threading) */

/***********************************************************************
*  This code is part of Statistics for MySQL.
*
*  Copyright (C) 2011 Heinrich Schuchardt (xypron.glpk@gmx.de)
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
***********************************************************************/

/**
 * @file sqlthread.h
 * @brief Definitions needed for using threads and mutexes.
 */
 
#ifndef SQLTHREAD_H

#define SQLTHREAD_H 1

#ifdef HAVE_CONF_H
#include "config.h"
#endif // HAVE_CONF_H

void sqlsleep(long msecs);
#ifdef SQLWIN
#include <windows.h>
typedef CRITICAL_SECTION pthread_mutex_t;
typedef DWORD pthread_t;
//@todo The return type of routine C is "DWORD" for Windows and "void *" for Posix.
//@todo The handle returned by CreateThread should be released with CloseHandle.
#define pthread_create(A,B,C,D)  (int)(CreateThread(NULL,0,(LPTHREAD_START_ROUTINE)&C,D,0,A)==NULL)
#define pthread_exit(A)          ExitThread(0)
#define pthread_mutex_destroy(A) DeleteCriticalSection(A)
#define pthread_mutex_init(A,B)  (InitializeCriticalSection(A),0)
#define pthread_mutex_lock(A)    (EnterCriticalSection(A),0)
#define pthread_mutex_unlock(A)  (LeaveCriticalSection(A),0)
#define pthread_self()           GetCurrentThreadId()
#else
#include <pthread.h>
#endif

#endif // SQLTHREAD_H
