/* testrand_norm.c (Variates of normal distribution) */

/***********************************************************************
*  This code is part of Statistics for MySQL.
*
*  Copyright (C) 2011 Heinrich Schuchardt (xypron.glpk@gmx.de)
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
***********************************************************************/

/**
 * @file testrand_norm.c
 * @brief Test variates of normal distribution.
 */
 
#include <stdlib.h>
#include <stdio.h>
#include "sqlstat.h"

/**
 * \fn int main(int argc, char *argv[])
 * @brief Main
 * @param argc number of arguments
 * @param argv arguments
 * @return success = EXIT_SUCCESS = 0
 */
int main(int argc, char *argv[]) {
  enum Item_result arg_type[1];
  double *p_args[2];
  
  UDF_INIT initid;
  UDF_ARGS udf_args;
  char error;
  char is_null;
  char message[MYSQL_ERRMSG_SIZE] = "\0";
  my_bool ret;
  
  int i;
  double actual;
  double expected;
  double x;
  double sum;
  double sum2;
  double mu;
  double sigma;

  printf ("Running test: %s\n", __FILE__);
  sqlstat_plugin_init(NULL);
  
  udf_args.arg_type = arg_type;
  p_args[0] = &sigma;
  p_args[1] = &mu;
  udf_args.args = (char **) p_args;

  /* Test init */
  udf_args.arg_count = 3;
  ret = rand_norm_init(&initid, &udf_args, message);
  if (ret == 0 ) {
    printf ("Number of arguments not checked\n");
    return EXIT_FAILURE;
  }

  /* Init */
  udf_args.arg_count = 0;
  ret = rand_norm_init(&initid, &udf_args, message);
  if (ret != 0 ) {
    printf ("Unexpexted error\n");
    return EXIT_FAILURE;
  }
  /* Test */
  sum = 0;
  sum2 = 0;
  for(i = 0; i < 1000000; i++) {
    x = rand_norm(&initid, &udf_args, &is_null, &error);
    sum  += x;
    sum2 += x * x;
  }
  actual = sum / 1000000.;
  expected = 0;
  if (fabs(actual - expected) >= 1E-2) {
    printf("Expected value: %f\nActual value: %f\n", expected, actual);
    return EXIT_FAILURE;
  }  
  actual = sum2 / 1000000.;
  expected = 1.;
  if (fabs(actual - expected) >= 1E-2) {
    printf("Expected value: %f\nActual value: %f\n", expected, actual);
    return EXIT_FAILURE;
  }  
  /* Deinit */
  rand_norm_deinit(&initid);

  /* Init */
  udf_args.arg_count = 2;
  ret = rand_norm_init(&initid, &udf_args, message);
  if (ret != 0 ) {
    printf ("Unexpexted error\n");
    return EXIT_FAILURE;
  }
  /* Test */
  sum = 0;
  sum2 = 0;
  mu = 4;
  sigma = 3.1;
  for(i = 0; i < 1000000; i++) {
    x = rand_norm(&initid, &udf_args, &is_null, &error);
    sum  += x;
    sum2 += (x-mu) * (x-mu);
  }
  actual = sum / 1000000.;
  expected = mu;
  if (fabs(actual - expected) >= 1E-2) {
    printf("Expected value: %f\nActual value: %f\n", expected, actual);
    return EXIT_FAILURE;
  }  
  actual = sum2 / 1000000. / sigma / sigma;
  expected = 1.;
  if (fabs(actual - expected) >= 1E-2) {
    printf("Expected value: %f\nActual value: %f\n", expected, actual);
    return EXIT_FAILURE;
  }  
  /* Deinit */
  rand_norm_deinit(&initid);
  
  sqlstat_plugin_deinit(NULL);
  
  printf("Test passed successfully: %s\n", __FILE__);
  
  return EXIT_SUCCESS;
}